@@ -1,9 +1,14 @@
+from __future__ import annotations
+
 import linecache
 
-from typing import Any, AsyncGenerator, Optional, Tuple
+from typing import TYPE_CHECKING, Any, AsyncGenerator, Optional, Tuple
 
 from .state import Machine
 
+if TYPE_CHECKING:
+    from .pdb.proxy import PdbCIState
+
 
 class Nextline:
     """Nextline allows line-by-line execution of concurrent Python scripts
@@ -30,12 +35,9 @@ class Nextline:
         # e.g., "<Nextline 'running'>"
         return f"<{self.__class__.__name__} {self.state!r}>"
 
-    def run(self) -> None:
-        """Execute the script"""
+    async def run(self) -> None:
+        """Execute the script and wait until it exits"""
         self.machine.run()
-
-    async def finish(self) -> None:
-        """Wait until the script execution exits"""
         await self.machine.finish()
 
     def exception(self) -> Optional[Exception]:
@@ -68,29 +70,24 @@ class Nextline:
         """
         return self.machine.state_name
 
-    async def subscribe_state(self) -> AsyncGenerator[str, None]:
-        # wish to be able to write with "yield from" but not possible
-        # https://stackoverflow.com/a/59079548/7309855
-        agen = self.registry.subscribe("state_name")
-        async for y in agen:
-            yield y
+    def subscribe_state(self) -> AsyncGenerator[str, None]:
+        return self.registry.subscribe("state_name")
 
     @property
     def run_no(self):
         """The current run number"""
         return self.registry.get("run_no")
 
-    async def subscribe_run_no(self):
-        agen = self.registry.subscribe("run_no")
-        async for y in agen:
-            yield y
+    def subscribe_run_no(self) -> AsyncGenerator[int, None]:
+        return self.registry.subscribe("run_no")
 
-    async def subscribe_trace_ids(self) -> AsyncGenerator[Tuple[int], None]:
-        agen = self.registry.subscribe("trace_ids")
-        async for y in agen:
-            yield y
+    def subscribe_trace_ids(self) -> AsyncGenerator[Tuple[int], None]:
+        return self.registry.subscribe("trace_ids")
 
-    async def subscribe_trace_state(self, trace_id: int):
+    async def subscribe_prompting(
+        self,
+        trace_id: int,
+    ) -> AsyncGenerator[PdbCIState, None]:
         agen = self.registry.subscribe(trace_id)
         async for y in agen:
             if y is None:
