@@ -1,7 +1,14 @@
+from __future__ import annotations
+
 import threading
 
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from pdb import Pdb
+    from queue import Queue
+
 
-##__________________________________________________________________||
 class PdbCommandInterface:
     """Relay pdb command prompts and commands
 
@@ -19,39 +26,41 @@ class PdbCommandInterface:
 
     """
 
-    def __init__(self, pdb, queue_in, queue_out):
-        self.pdb = pdb
-        self.queue_in = queue_in
-        self.queue_out = queue_out
-        self.ended = False
-        self.nprompts = 0
+    def __init__(self, pdb: Pdb, queue_in: Queue, queue_out: Queue):
+        self._pdb = pdb
+        self._queue_in = queue_in
+        self._queue_out = queue_out
+        self._ended = False
+        self._nprompts = 0
 
-    def send_pdb_command(self, command):
+    def send_pdb_command(self, command: str) -> None:
         """send a command to pdb"""
-        self.command = command
-        self.queue_in.put(command)
+        self._command = command
+        self._queue_in.put(command)
 
-    def start(self):
+    def start(self) -> None:
         """start interfacing the pdb"""
-        self.thread = threading.Thread(target=self._receive_pdb_stdout)
-        self.thread.start()
+        self._thread = threading.Thread(target=self._receive_pdb_stdout)
+        self._thread.start()
 
-    def end(self):
+    def end(self) -> None:
         """end interfacing the pdb"""
-        self.ended = True
-        self.queue_out.put(None)  # end the thread
-        self.thread.join()
+        self._ended = True
+        self._queue_out.put(None)  # end the thread
+        self._thread.join()
 
     def _receive_pdb_stdout(self):
         """receive stdout from pdb
 
         This method runs in its own thread during pdb._cmdloop()
         """
-        while out := self._read_uptp_prompt(self.queue_out, self.pdb.prompt):
-            self.nprompts += 1
-            self.stdout = out
+        while out := self._read_until_prompt(
+            self._queue_out, self._pdb.prompt
+        ):
+            self._nprompts += 1
+            self._stdout = out
 
-    def _read_uptp_prompt(self, queue, prompt):
+    def _read_until_prompt(self, queue, prompt):
         """read the queue up to the prompt"""
         out = ""
         while True:
@@ -62,6 +71,3 @@ class PdbCommandInterface:
             if prompt == m:
                 break
         return out
-
-
-##__________________________________________________________________||
