@@ -3,18 +3,19 @@ from __future__ import annotations
 import asyncio
 from threading import Thread
 import itertools
-from typing import Optional, Any
+from typing import TYPE_CHECKING, Dict, Optional, Any
 
 from .trace import Trace
-from .registry import PdbCIRegistry
 from .utils import SubscribableDict, ThreadSafeAsyncioEvent, to_thread
 from .call import call_with_trace
 from . import script
 
+if TYPE_CHECKING:
+    from .pdb.ci import PdbCommandInterface
+
 SCRIPT_FILE_NAME = "<string>"
 
 
-# __________________________________________________________________||
 class Machine:
     """State machine
 
@@ -56,17 +57,20 @@ class Machine:
         self.registry["run_no_count"] = itertools.count(
             run_no_start_from
         ).__next__
-        self.registry["thread_task_ids"] = ()
-
-        self._state: State = Initialized(self.registry)
 
         self._lock_finish = asyncio.Condition()
         self._lock_close = asyncio.Condition()
 
+        self._state: State = Initialized(self.registry)
+        self._state_changed()
+
     def __repr__(self):
         # e.g., "<Machine 'running'>"
         return f"<{self.__class__.__name__} {self.state_name!r}>"
 
+    def _state_changed(self) -> None:
+        self.registry["state_name"] = self.state_name
+
     @property
     def state_name(self) -> str:
         """e.g., "initialized", "running","""
@@ -78,6 +82,7 @@ class Machine:
     def run(self) -> None:
         """Enter the running state"""
         self._state = self._state.run()
+        self._state_changed()
         self._task_exited = asyncio.create_task(self._exited())
 
     async def _exited(self) -> None:
@@ -90,6 +95,7 @@ class Machine:
         """
 
         self._state = await self._state.exited()
+        self._state_changed()
 
     def send_pdb_command(self, thread_asynctask_id, command) -> None:
         self._state.send_pdb_command(thread_asynctask_id, command)
@@ -99,6 +105,7 @@ class Machine:
         await self._task_exited
         async with self._lock_finish:
             self._state = await self._state.finish()
+            self._state_changed()
 
     def exception(self) -> Optional[Exception]:
         return self._state.exception()
@@ -111,15 +118,16 @@ class Machine:
         if statement:
             self.registry["statement"] = statement
         self._state = self._state.reset()
+        self._state_changed()
 
     async def close(self) -> None:
         """Enter the closed state"""
         async with self._lock_close:
             self._state = self._state.close()
+            self._state_changed()
             await to_thread(self.registry.close)
 
 
-# __________________________________________________________________||
 class StateObsoleteError(Exception):
     """Operation on an obsolete state object."""
 
@@ -132,7 +140,6 @@ class StateMethodError(Exception):
     pass
 
 
-# __________________________________________________________________||
 class ObsoleteMixin:
     def assert_not_obsolete(self):
         if self.is_obsolete():
@@ -177,7 +184,8 @@ class State(ObsoleteMixin):
         self.assert_not_obsolete()
         raise StateMethodError(f"Irrelevant operation on the state: {self!r}")
 
-    def send_pdb_command(self, *_, **__) -> None:
+    def send_pdb_command(self, trace_id: int, command: str) -> None:
+        del trace_id, command
         raise StateMethodError(f"Irrelevant operation on the state: {self!r}")
 
     def exception(self) -> Optional[Exception]:
@@ -201,9 +209,8 @@ class Initialized(State):
 
     def __init__(self, registry: SubscribableDict):
         self.registry = registry
-        run_no = self.registry.get("run_no_count")()
+        run_no = self.registry.get("run_no_count")()  # type: ignore
         self.registry["run_no"] = run_no
-        self.registry["state_name"] = self.name
 
     def run(self):
         self.assert_not_obsolete()
@@ -241,14 +248,11 @@ class Running(State):
 
         statement = self.registry.get("statement")
 
-        self.pdb_ci_registry = PdbCIRegistry()
+        self._pdb_ci_map: Dict[int, PdbCommandInterface] = {}
         trace = Trace(
             registry=self.registry,
-            pdb_ci_registry=self.pdb_ci_registry,
+            pdb_ci_map=self._pdb_ci_map,
         )
-        # self.pdb_ci_registry = trace.pdb_ci_registry
-
-        self.registry["state_name"] = self.name
 
         self.loop = asyncio.get_running_loop()
 
@@ -298,8 +302,8 @@ class Running(State):
         self.obsolete()
         return self._exited
 
-    def send_pdb_command(self, thread_asynctask_id, command):
-        pdb_ci = self.pdb_ci_registry.get_ci(thread_asynctask_id)
+    def send_pdb_command(self, trace_id: int, command: str) -> None:
+        pdb_ci = self._pdb_ci_map[trace_id]
         pdb_ci.send_pdb_command(command)
 
 
@@ -328,8 +332,6 @@ class Exited(State):
         self._result = result
         self._exception = exception
 
-        self.registry["state_name"] = self.name
-
     async def finish(self):
         self.assert_not_obsolete()
         await to_thread(self._thread.join)
@@ -363,7 +365,6 @@ class Finished(State):
         self._exception = exception
 
         self.registry = registry
-        self.registry["state_name"] = self.name
 
     def exception(self):
         """Return the exception of the script execution
@@ -421,11 +422,7 @@ class Closed(State):
 
     def __init__(self, registry: SubscribableDict):
         self.registry = registry
-        self.registry["state_name"] = self.name
 
     def close(self):
         self.assert_not_obsolete()
         return self
-
-
-# __________________________________________________________________||
