@@ -4,7 +4,7 @@ from weakref import WeakKeyDictionary
 
 import fnmatch
 
-from typing import Any, Set, Optional, Union, Callable, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Set, Dict, Optional, Union, Callable
 from types import FrameType
 
 from .pdb.proxy import PdbInterfaceFactory
@@ -13,8 +13,7 @@ from .utils import current_task_or_thread
 if TYPE_CHECKING:
     from .types import TraceFunc
     from .utils import SubscribableDict
-    from .pdb.proxy import PdbInterface
-    from .registry import PdbCIRegistry
+    from .pdb.ci import PdbCommandInterface
 
 
 MODULES_TO_SKIP = {
@@ -48,7 +47,7 @@ MODULES_TO_SKIP = {
 
 def Trace(
     registry: SubscribableDict,
-    pdb_ci_registry: PdbCIRegistry,
+    pdb_ci_map: Dict[int, PdbCommandInterface],
     modules_to_trace: Optional[Set[str]] = None,
 ) -> TraceFunc:
     """Create the main trace function
@@ -73,16 +72,15 @@ def Trace(
     # modules_to_trace will be shared and modified by
     # multiple objects.
 
-    create_pdbi = PdbInterfaceFactory(
+    pdbi_factory = PdbInterfaceFactory(
         registry=registry,
-        pdb_ci_registry=pdb_ci_registry,
+        pdb_ci_map=pdb_ci_map,
         modules_to_trace=modules_to_trace,
     )
 
     def create_trace_for_single_thread_or_task():
         """To be called in the thread or task to be traced"""
-        pdbi = create_pdbi()
-        trace_call_pdb = TraceCallPdb(pdbi=pdbi)
+        trace_call_pdb = TraceFromFactory(factory=lambda: pdbi_factory().trace)
         return TraceSelectFirstModule(
             trace=trace_call_pdb,
             modules_to_trace=modules_to_trace,
@@ -130,19 +128,21 @@ def TraceAddFirstModule(
         if not first:
             return trace(frame, event, arg)
 
-        def create_local_trace():
+        def create_local_trace() -> TraceFunc:
             next_trace: Union[TraceFunc, None] = trace
 
-            def local_trace(frame, event, arg):
+            def local_trace(frame, event, arg) -> Optional[TraceFunc]:
                 nonlocal first, next_trace
+                assert next_trace
 
                 if module_name := frame.f_globals.get("__name__"):
                     first = False
                     modules_to_trace.add(module_name)
                     return trace(frame, event, arg)
 
-                next_trace = next_trace(frame, event, arg)
-                return local_trace
+                if next_trace := next_trace(frame, event, arg):
+                    return local_trace
+                return None
 
             return local_trace
 
@@ -185,32 +185,20 @@ def TraceSelectFirstModule(
     return ret
 
 
-def TraceCallPdb(pdbi: PdbInterface) -> TraceFunc:
+def TraceFromFactory(factory: Callable[[], TraceFunc]) -> TraceFunc:
+    """Create a trace that creates a trace first time called
 
-    pdb_trace: Union[TraceFunc, None] = None
-    # Instead of calling pdbi.open() here, set initially None so that
-    # pdbi.open() won't be called unless global_trace() is actually
-    # called.
+    Useful when desirable to defer the creation until actually called
+
+    It is used to avoid creating instances of Pdb in threads or async tasks
+    that are not traced.
+    """
+    trace: Union[TraceFunc, None] = None
 
     def global_trace(frame, event, arg) -> Optional[TraceFunc]:
-        nonlocal pdb_trace
-        if not pdb_trace:
-            pdb_trace = pdbi.open()  # Bdb.trace_dispatch
-
-        def create_local_trace():
-            next_trace: Union[TraceFunc, None] = pdb_trace
-
-            def local_trace(frame, event, arg):
-                nonlocal next_trace
-                pdbi.calling_trace(frame, event, arg)
-                next_trace = next_trace(frame, event, arg)
-                pdbi.exited_trace()
-                if next_trace:
-                    return local_trace
-
-            return local_trace
-
-        return create_local_trace()(frame, event, arg)
+        nonlocal trace
+        trace = trace or factory()
+        return trace(frame, event, arg)
 
     return global_trace
 
