@@ -1,13 +1,16 @@
 from .queuedist import QueueDist  # noqa: F401
 from .thread_task_id import UniqThreadTaskIdComposer  # noqa: F401
 from .thread_safe_event import ThreadSafeAsyncioEvent  # noqa: F401
-from .coro_runner import CoroutineRunner  # noqa: F401
 from .loop import ToLoop  # noqa: F401
-from .registry import Registry  # noqa: F401
+from .subscribabledict import SubscribableDict  # noqa: F401
 from .thread_exception import ExcThread  # noqa: F401
 from .done_callback import (  # noqa: F401
     ThreadTaskDoneCallback,
     ThreadDoneCallback,
     TaskDoneCallback,
 )
-from .func import current_task_or_thread, to_thread  # noqa: F401
+from .func import (  # noqa: F401
+    current_task_or_thread,
+    to_thread,
+    agen_with_wait,
+)
