@@ -16,7 +16,7 @@ async def test_run():
     nextline = Nextline(statement)
     assert nextline.state == "initialized"
 
-    nextline.run()
+    run = asyncio.create_task(nextline.run())
 
     await asyncio.sleep(0.01)
 
@@ -30,13 +30,13 @@ async def test_run():
             break
 
     n_prompting = 0
-    async for state in nextline.subscribe_trace_state(trace_id):
-        if state["prompting"]:
+    async for state in nextline.subscribe_prompting(trace_id):
+        if state.prompting:
             n_prompting += 1
             nextline.send_pdb_command(trace_id, "next")
     assert 3 == n_prompting
 
-    await nextline.finish()
+    await run
     assert nextline.state == "finished"
     await nextline.close()
     assert nextline.state == "closed"
