@@ -1,8 +1,8 @@
 import asyncio
-from typing import AsyncIterable, Iterable
+from typing import AsyncGenerator, Iterable, Any
 
 
-async def aiterable(iterable: Iterable) -> AsyncIterable:
+async def aiterable(iterable: Iterable) -> AsyncGenerator[Any, None]:
     '''Wrap iterable so can be used with "async for"'''
     for i in iterable:
         await asyncio.sleep(0)  # let other tasks run
